#!/usr/bin/env python

class Nekogirl():
    def __init__(self, name):
        self.name = name

    def 名字(self):
        return self.name

    def 喵喵喵(self):
        print('喵喵喵')

    def 变(self):
        print('变好了')


if __name__ == '__main__':
    my_nekogirl = Nekogirl('sweety')



#!/usr/bin/env python

from setuptools import setup

setup(
    name='nekogirl',
    version='0.0.2',
    author='mcwindy',
    author_email='chen_yuyang@outlook.com',
    url='https://github.com/mcwindy/nekogirl',
    description='这个代码提供了猫娘',
    packages=['nekogirl'],
    install_requires=[],
    entry_points={
        'console_scripts': [
            'Nekogirl=nekogirl:Nekogirl'
        ]
    }
)
